@@ -6,8 +6,9 @@ OpenLink Python Utils - Reusable utilities for caching, data manipulation, parsi
 from . import core
 from . import cache
 from . import query
+from . import reports
 
-__version__ = "1.1.4"
+__version__ = "1.1.5"
 __author__ = "OpenLink SpA"
 
-__all__ = ["core", "cache", "query", "__version__"]
+__all__ = ["core", "cache", "query", "reports", "__version__"]
